You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ap...@apache.org on 2024/01/12 09:23:44 UTC

(camel) branch main updated: Regen endpointdsl

This is an automated email from the ASF dual-hosted git repository.

apupier pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 50ba801da5a Regen endpointdsl
50ba801da5a is described below

commit 50ba801da5adff746e948f7321646d986e7877b8
Author: Aurélien Pupier <ap...@redhat.com>
AuthorDate: Fri Jan 12 10:05:04 2024 +0100

    Regen endpointdsl
    
    Signed-off-by: Aurélien Pupier <ap...@redhat.com>
---
 .../builder/endpoint/StaticEndpointBuilders.java   |  44 ++++-----
 ...DynamicRouterControlEndpointBuilderFactory.java |  14 +--
 .../dsl/FileWatchEndpointBuilderFactory.java       |   4 +-
 .../endpoint/dsl/FtpEndpointBuilderFactory.java    |   4 +-
 .../endpoint/dsl/FtpsEndpointBuilderFactory.java   |   4 +-
 .../dsl/RobotFrameworkEndpointBuilderFactory.java  |   8 +-
 .../dsl/SalesforceEndpointBuilderFactory.java      | 101 +++++++++++++++++----
 .../endpoint/dsl/SftpEndpointBuilderFactory.java   |   4 +-
 8 files changed, 126 insertions(+), 57 deletions(-)

diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
index 27c33688cd6..3e8f7a687a6 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
@@ -4241,15 +4241,15 @@ public class StaticEndpointBuilders {
      * message routing.
      * 
      * Category: messaging
-     * Since: 4.3
+     * Since: 4.4
      * Maven coordinates: org.apache.camel:camel-dynamic-router
      * 
      * Syntax: <code>dynamic-router-control:controlAction</code>
      * 
      * Path parameter: controlAction (required)
      * Control action
-     * There are 3 enums and the value can be one of: subscribe, unsubscribe,
-     * list
+     * There are 5 enums and the value can be one of: subscribe, unsubscribe,
+     * update, list, statistics
      * 
      * @param path controlAction
      * @return the dsl builder
@@ -4265,15 +4265,15 @@ public class StaticEndpointBuilders {
      * message routing.
      * 
      * Category: messaging
-     * Since: 4.3
+     * Since: 4.4
      * Maven coordinates: org.apache.camel:camel-dynamic-router
      * 
      * Syntax: <code>dynamic-router-control:controlAction</code>
      * 
      * Path parameter: controlAction (required)
      * Control action
-     * There are 3 enums and the value can be one of: subscribe, unsubscribe,
-     * list
+     * There are 5 enums and the value can be one of: subscribe, unsubscribe,
+     * update, list, statistics
      * 
      * @param componentName to use a custom component name for the endpoint
      * instead of the default name
@@ -12347,7 +12347,7 @@ public class StaticEndpointBuilders {
     }
     /**
      * Robot Framework (camel-robotframework)
-     * Pass camel exchanges to acceptence test written in Robot DSL.
+     * Pass camel exchanges to acceptance test written in Robot DSL.
      * 
      * Category: testing
      * Since: 3.0
@@ -12373,7 +12373,7 @@ public class StaticEndpointBuilders {
     }
     /**
      * Robot Framework (camel-robotframework)
-     * Pass camel exchanges to acceptence test written in Robot DSL.
+     * Pass camel exchanges to acceptance test written in Robot DSL.
      * 
      * Category: testing
      * Since: 3.0
@@ -12543,16 +12543,16 @@ public class StaticEndpointBuilders {
      * 
      * Path parameter: operationName (required)
      * The operation to use
-     * There are 68 enums and the value can be one of: getVersions,
+     * There are 69 enums and the value can be one of: getVersions,
      * getResources, getGlobalObjects, getBasicInfo, getDescription, getSObject,
      * createSObject, updateSObject, deleteSObject, getSObjectWithId,
      * upsertSObject, deleteSObjectWithId, getBlobField, query, queryMore,
-     * queryAll, search, apexCall, recent, createJob, getJob, closeJob,
-     * abortJob, createBatch, getBatch, getAllBatches, getRequest, getResults,
-     * createBatchQuery, getQueryResultIds, getQueryResult, getRecentReports,
-     * getReportDescription, executeSyncReport, executeAsyncReport,
-     * getReportInstances, getReportResults, limits, approval, approvals,
-     * composite-tree, composite-batch, composite,
+     * queryAll, search, apexCall, recent, getEventSchema, createJob, getJob,
+     * closeJob, abortJob, createBatch, getBatch, getAllBatches, getRequest,
+     * getResults, createBatchQuery, getQueryResultIds, getQueryResult,
+     * getRecentReports, getReportDescription, executeSyncReport,
+     * executeAsyncReport, getReportInstances, getReportResults, limits,
+     * approval, approvals, composite-tree, composite-batch, composite,
      * compositeRetrieveSObjectCollections, compositeCreateSObjectCollections,
      * compositeUpdateSObjectCollections, compositeUpsertSObjectCollections,
      * compositeDeleteSObjectCollections, bulk2GetAllJobs, bulk2CreateJob,
@@ -12584,16 +12584,16 @@ public class StaticEndpointBuilders {
      * 
      * Path parameter: operationName (required)
      * The operation to use
-     * There are 68 enums and the value can be one of: getVersions,
+     * There are 69 enums and the value can be one of: getVersions,
      * getResources, getGlobalObjects, getBasicInfo, getDescription, getSObject,
      * createSObject, updateSObject, deleteSObject, getSObjectWithId,
      * upsertSObject, deleteSObjectWithId, getBlobField, query, queryMore,
-     * queryAll, search, apexCall, recent, createJob, getJob, closeJob,
-     * abortJob, createBatch, getBatch, getAllBatches, getRequest, getResults,
-     * createBatchQuery, getQueryResultIds, getQueryResult, getRecentReports,
-     * getReportDescription, executeSyncReport, executeAsyncReport,
-     * getReportInstances, getReportResults, limits, approval, approvals,
-     * composite-tree, composite-batch, composite,
+     * queryAll, search, apexCall, recent, getEventSchema, createJob, getJob,
+     * closeJob, abortJob, createBatch, getBatch, getAllBatches, getRequest,
+     * getResults, createBatchQuery, getQueryResultIds, getQueryResult,
+     * getRecentReports, getReportDescription, executeSyncReport,
+     * executeAsyncReport, getReportInstances, getReportResults, limits,
+     * approval, approvals, composite-tree, composite-batch, composite,
      * compositeRetrieveSObjectCollections, compositeCreateSObjectCollections,
      * compositeUpdateSObjectCollections, compositeUpsertSObjectCollections,
      * compositeDeleteSObjectCollections, bulk2GetAllJobs, bulk2CreateJob,
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DynamicRouterControlEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DynamicRouterControlEndpointBuilderFactory.java
index 91857ea9b5a..c8da3cb09ff 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DynamicRouterControlEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DynamicRouterControlEndpointBuilderFactory.java
@@ -252,7 +252,7 @@ public interface DynamicRouterControlEndpointBuilderFactory {
          * message routing.
          * 
          * Category: messaging
-         * Since: 4.3
+         * Since: 4.4
          * Maven coordinates: org.apache.camel:camel-dynamic-router
          * 
          * @return the dsl builder for the headers' name.
@@ -267,15 +267,15 @@ public interface DynamicRouterControlEndpointBuilderFactory {
          * message routing.
          * 
          * Category: messaging
-         * Since: 4.3
+         * Since: 4.4
          * Maven coordinates: org.apache.camel:camel-dynamic-router
          * 
          * Syntax: <code>dynamic-router-control:controlAction</code>
          * 
          * Path parameter: controlAction (required)
          * Control action
-         * There are 3 enums and the value can be one of: subscribe,
-         * unsubscribe, list
+         * There are 5 enums and the value can be one of: subscribe,
+         * unsubscribe, update, list, statistics
          * 
          * @param path controlAction
          * @return the dsl builder
@@ -291,15 +291,15 @@ public interface DynamicRouterControlEndpointBuilderFactory {
          * message routing.
          * 
          * Category: messaging
-         * Since: 4.3
+         * Since: 4.4
          * Maven coordinates: org.apache.camel:camel-dynamic-router
          * 
          * Syntax: <code>dynamic-router-control:controlAction</code>
          * 
          * Path parameter: controlAction (required)
          * Control action
-         * There are 3 enums and the value can be one of: subscribe,
-         * unsubscribe, list
+         * There are 5 enums and the value can be one of: subscribe,
+         * unsubscribe, update, list, statistics
          * 
          * @param componentName to use a custom component name for the endpoint
          * instead of the default name
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FileWatchEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FileWatchEndpointBuilderFactory.java
index 33d6c06541a..591a1a22ed2 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FileWatchEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FileWatchEndpointBuilderFactory.java
@@ -60,7 +60,7 @@ public interface FileWatchEndpointBuilderFactory {
             return this;
         }
         /**
-         * Auto create directory if does not exists.
+         * Auto create directory if does not exist.
          * 
          * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
          * 
@@ -75,7 +75,7 @@ public interface FileWatchEndpointBuilderFactory {
             return this;
         }
         /**
-         * Auto create directory if does not exists.
+         * Auto create directory if does not exist.
          * 
          * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
          * type.
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpEndpointBuilderFactory.java
index ff2c839ae78..20f1b1708fc 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpEndpointBuilderFactory.java
@@ -2472,7 +2472,7 @@ public interface FtpEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          * 
@@ -2492,7 +2492,7 @@ public interface FtpEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpsEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpsEndpointBuilderFactory.java
index d2689a17d2c..e0ef666651f 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpsEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/FtpsEndpointBuilderFactory.java
@@ -2725,7 +2725,7 @@ public interface FtpsEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          * 
@@ -2745,7 +2745,7 @@ public interface FtpsEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/RobotFrameworkEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/RobotFrameworkEndpointBuilderFactory.java
index ebbfa470bb7..56fc121f395 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/RobotFrameworkEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/RobotFrameworkEndpointBuilderFactory.java
@@ -27,7 +27,7 @@ import org.apache.camel.builder.EndpointProducerBuilder;
 import org.apache.camel.builder.endpoint.AbstractEndpointBuilder;
 
 /**
- * Pass camel exchanges to acceptence test written in Robot DSL.
+ * Pass camel exchanges to acceptance test written in Robot DSL.
  * 
  * Generated by camel build tools - do NOT edit this file!
  */
@@ -3587,7 +3587,7 @@ public interface RobotFrameworkEndpointBuilderFactory {
     public interface RobotFrameworkBuilders {
         /**
          * Robot Framework (camel-robotframework)
-         * Pass camel exchanges to acceptence test written in Robot DSL.
+         * Pass camel exchanges to acceptance test written in Robot DSL.
          * 
          * Category: testing
          * Since: 3.0
@@ -3600,7 +3600,7 @@ public interface RobotFrameworkEndpointBuilderFactory {
         }
         /**
          * Robot Framework (camel-robotframework)
-         * Pass camel exchanges to acceptence test written in Robot DSL.
+         * Pass camel exchanges to acceptance test written in Robot DSL.
          * 
          * Category: testing
          * Since: 3.0
@@ -3626,7 +3626,7 @@ public interface RobotFrameworkEndpointBuilderFactory {
         }
         /**
          * Robot Framework (camel-robotframework)
-         * Pass camel exchanges to acceptence test written in Robot DSL.
+         * Pass camel exchanges to acceptance test written in Robot DSL.
          * 
          * Category: testing
          * Since: 3.0
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SftpEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SftpEndpointBuilderFactory.java
index 04040dfb761..bd43e9c39e8 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SftpEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SftpEndpointBuilderFactory.java
@@ -2780,7 +2780,7 @@ public interface SftpEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          * 
@@ -2800,7 +2800,7 @@ public interface SftpEndpointBuilderFactory {
         /**
          * Whether to ignore when (trying to list files in directories or when
          * downloading a file), which does not exist or due to permission error.
-         * By default when a directory or file does not exists or insufficient
+         * By default when a directory or file does not exist or insufficient
          * permission, then an exception is thrown. Setting this option to true
          * allows to ignore that instead.
          *
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SalesforceEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SalesforceEndpointBuilderFactory.java
index 54a26c5a0c4..ec7227f9dc1 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SalesforceEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/SalesforceEndpointBuilderFactory.java
@@ -2765,6 +2765,73 @@ public interface SalesforceEndpointBuilderFactory {
             doSetProperty("compositeMethod", compositeMethod);
             return this;
         }
+        /**
+         * Name of Platform Event, Change Data Capture Event, custom event, etc.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param eventName the value to set
+         * @return the dsl builder
+         */
+        default SalesforceEndpointProducerBuilder eventName(String eventName) {
+            doSetProperty("eventName", eventName);
+            return this;
+        }
+        /**
+         * EXPANDED: Apache Avro format but doesnt strictly adhere to the record
+         * complex type. COMPACT: Apache Avro, adheres to the specification for
+         * the record complex type. This parameter is available in API version
+         * 43.0 and later.
+         * 
+         * The option is a:
+         * &lt;code&gt;org.apache.camel.component.salesforce.internal.dto.EventSchemaFormatEnum&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param eventSchemaFormat the value to set
+         * @return the dsl builder
+         */
+        default SalesforceEndpointProducerBuilder eventSchemaFormat(
+                org.apache.camel.component.salesforce.internal.dto.EventSchemaFormatEnum eventSchemaFormat) {
+            doSetProperty("eventSchemaFormat", eventSchemaFormat);
+            return this;
+        }
+        /**
+         * EXPANDED: Apache Avro format but doesnt strictly adhere to the record
+         * complex type. COMPACT: Apache Avro, adheres to the specification for
+         * the record complex type. This parameter is available in API version
+         * 43.0 and later.
+         * 
+         * The option will be converted to a
+         * &lt;code&gt;org.apache.camel.component.salesforce.internal.dto.EventSchemaFormatEnum&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param eventSchemaFormat the value to set
+         * @return the dsl builder
+         */
+        default SalesforceEndpointProducerBuilder eventSchemaFormat(
+                String eventSchemaFormat) {
+            doSetProperty("eventSchemaFormat", eventSchemaFormat);
+            return this;
+        }
+        /**
+         * The ID of the event schema.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param eventSchemaId the value to set
+         * @return the dsl builder
+         */
+        default SalesforceEndpointProducerBuilder eventSchemaId(
+                String eventSchemaId) {
+            doSetProperty("eventSchemaId", eventSchemaId);
+            return this;
+        }
         /**
          * Comma separated list of message headers to include as HTTP parameters
          * for Raw operation.
@@ -4097,17 +4164,18 @@ public interface SalesforceEndpointBuilderFactory {
          * 
          * Path parameter: operationName (required)
          * The operation to use
-         * There are 68 enums and the value can be one of: getVersions,
+         * There are 69 enums and the value can be one of: getVersions,
          * getResources, getGlobalObjects, getBasicInfo, getDescription,
          * getSObject, createSObject, updateSObject, deleteSObject,
          * getSObjectWithId, upsertSObject, deleteSObjectWithId, getBlobField,
          * query, queryMore, queryAll, search, apexCall, recent, createJob,
          * getJob, closeJob, abortJob, createBatch, getBatch, getAllBatches,
          * getRequest, getResults, createBatchQuery, getQueryResultIds,
          * getQueryResult, getRecentReports, getReportDescription,
          * executeSyncReport, executeAsyncReport, getReportInstances,
          * getReportResults, limits, approval, approvals, composite-tree,
          * composite-batch, composite, compositeRetrieveSObjectCollections,
          * compositeCreateSObjectCollections, compositeUpdateSObjectCollections,
          * compositeUpsertSObjectCollections, compositeDeleteSObjectCollections,
          * bulk2GetAllJobs, bulk2CreateJob, bulk2GetJob, bulk2CreateBatch,
@@ -4138,17 +4206,18 @@ public interface SalesforceEndpointBuilderFactory {
          * 
          * Path parameter: operationName (required)
          * The operation to use
-         * There are 68 enums and the value can be one of: getVersions,
+         * There are 69 enums and the value can be one of: getVersions,
          * getResources, getGlobalObjects, getBasicInfo, getDescription,
          * getSObject, createSObject, updateSObject, deleteSObject,
          * getSObjectWithId, upsertSObject, deleteSObjectWithId, getBlobField,
          * query, queryMore, queryAll, search, apexCall, recent, createJob,
          * getJob, closeJob, abortJob, createBatch, getBatch, getAllBatches,
          * getRequest, getResults, createBatchQuery, getQueryResultIds,
          * getQueryResult, getRecentReports, getReportDescription,
          * executeSyncReport, executeAsyncReport, getReportInstances,
          * getReportResults, limits, approval, approvals, composite-tree,
          * composite-batch, composite, compositeRetrieveSObjectCollections,
          * compositeCreateSObjectCollections, compositeUpdateSObjectCollections,
          * compositeUpsertSObjectCollections, compositeDeleteSObjectCollections,
          * bulk2GetAllJobs, bulk2CreateJob, bulk2GetJob, bulk2CreateBatch,
@@ -4097,17 +4164,18 @@ public interface SalesforceEndpointBuilderFactory {
          * getSObject, createSObject, updateSObject, deleteSObject,
          * getSObjectWithId, upsertSObject, deleteSObjectWithId, getBlobField,
-         * query, queryMore, queryAll, search, apexCall, recent, createJob,
-         * getJob, closeJob, abortJob, createBatch, getBatch, getAllBatches,
-         * getRequest, getResults, createBatchQuery, getQueryResultIds,
-         * getQueryResult, getRecentReports, getReportDescription,
-         * executeSyncReport, executeAsyncReport, getReportInstances,
-         * getReportResults, limits, approval, approvals, composite-tree,
-         * composite-batch, composite, compositeRetrieveSObjectCollections,
+         * query, queryMore, queryAll, search, apexCall, recent, getEventSchema,
+         * createJob, getJob, closeJob, abortJob, createBatch, getBatch,
+         * getAllBatches, getRequest, getResults, createBatchQuery,
+         * getQueryResultIds, getQueryResult, getRecentReports,
+         * getReportDescription, executeSyncReport, executeAsyncReport,
+         * getReportInstances, getReportResults, limits, approval, approvals,
+         * composite-tree, composite-batch, composite,
+         * compositeRetrieveSObjectCollections,
          * compositeCreateSObjectCollections, compositeUpdateSObjectCollections,
          * compositeUpsertSObjectCollections, compositeDeleteSObjectCollections,
@@ -4138,17 +4206,18 @@ public interface SalesforceEndpointBuilderFactory {
          * getSObject, createSObject, updateSObject, deleteSObject,
          * getSObjectWithId, upsertSObject, deleteSObjectWithId, getBlobField,
-         * query, queryMore, queryAll, search, apexCall, recent, createJob,
-         * getJob, closeJob, abortJob, createBatch, getBatch, getAllBatches,
-         * getRequest, getResults, createBatchQuery, getQueryResultIds,
-         * getQueryResult, getRecentReports, getReportDescription,
-         * executeSyncReport, executeAsyncReport, getReportInstances,
-         * getReportResults, limits, approval, approvals, composite-tree,
-         * composite-batch, composite, compositeRetrieveSObjectCollections,
+         * query, queryMore, queryAll, search, apexCall, recent, getEventSchema,
+         * createJob, getJob, closeJob, abortJob, createBatch, getBatch,
+         * getAllBatches, getRequest, getResults, createBatchQuery,
+         * getQueryResultIds, getQueryResult, getRecentReports,
+         * getReportDescription, executeSyncReport, executeAsyncReport,
+         * getReportInstances, getReportResults, limits, approval, approvals,
+         * composite-tree, composite-batch, composite,
+         * compositeRetrieveSObjectCollections,
          * compositeCreateSObjectCollections, compositeUpdateSObjectCollections,
          * compositeUpsertSObjectCollections, compositeDeleteSObjectCollections,